



if not exist %PREFIX%\\Library\\include\\radar\\api.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\radar\\estimator_cw.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\radar\\tracking_singletarget.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\bin\\gnuradio-radar.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\gnuradio-radar.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_crop_matrix_vcvc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_estimator_cw.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_find_max_peak_c.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_msg_gate.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_ofdm_cyclic_prefix_remover_cvc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_os_cfar_2d_vc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_print_results.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_qtgui_scatter_plot.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_signal_generator_cw_c.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_split_cc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_static_target_simulator_cc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_tracking_singletarget.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_transpose_matrix_vcvc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_trigger_command.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_ts_fft_cc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\radar_usrp_echotimer_cc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
